==> omnibuild-0.1.0%2B2.tar.gz: bin/omnibuild.dart <==
// Copyright (c) 2015, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by a MIT-style license
// that can be found in the LICENSE file.

library omnibuild.cli;

import 'dart:io';

import 'package:args/args.dart';
import 'package:yaml/yaml.dart';
import 'package:path/path.dart' as path;
import 'package:omnibuild/omnibuild.dart';

/// Omnibus message builder
///
/// This executable generates Dart code from YAML Omnibus message
/// specifications. More details can be found in `doc/omnibuild.md`.
void main(List<String> args) {
  // Create CLI args parser.
  var parser = new ArgParser();
  parser.addOption('output', abbr: 'o', help: 'Output directory.');

  // Parse CLI args.
  final options = parser.parse(args);
  String outputDir = options['output'];

  // Read package name and version from pubspec.yaml.
  YamlMap pubspec = loadYaml(new File('./pubspec.yaml').readAsStringSync());
  String packageName = pubspec['name'];
  String packageVersion = pubspec['version'];
  var pubMajorVersion = int.parse(packageVersion[0]);

  // Loop through input files.
  var pathMatcher = new RegExp(r'.v(\d+).yaml$');
  options.rest.forEach((String filepath) {
    var r = pathMatcher.firstMatch(filepath);

    if (r == null) {
      // Show error message if the file does not contain a version number.
      print('No version number was found in $filepath (file skipped)');
    } else if (int.parse(r.group(1)) > pubMajorVersion) {
      // Show error message if the file version is larger than the pub major
      // version.
      print(
          'Pub major version ($pubMajorVersion) is smaller than the version of $filepath (file skipped)');
    } else {
      // Parse file.
      var spec = new OmnibuildSpecFile.fromYaml(
          new File(filepath).readAsStringSync(),
          int.parse(r.group(1)),
          packageName);

      // Generate code.
      var code = spec.generateCode();

      // Write to output file.
      new File(outputDir + path.basenameWithoutExtension(filepath) + '.dart')
          .writeAsStringSync(code);
    }
  });
}

==> omnibuild-0.5.1%2B2.tar.gz: bin/omnibuild.dart <==
// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by a MIT-style license
// that can be found in the LICENSE file.

library omnibuild.cli;

import 'dart:io';

import 'package:args/args.dart';
import 'package:yaml/yaml.dart';
import 'package:path/path.dart' as path;
import 'package:omnibuild/omnibuild.dart';

/// Package version (automatically refresed in pre-commit.sh)
const omnibuildBinaryVersion = '0.5.1+2';

/// Omnibus message builder
///
/// This executable generates Dart code from YAML Omnibus message
/// specifications. More details can be found in `doc/omnibuild.md`.=
void main(List<String> args) {
  // Create CLI args parser.
  var parser = new ArgParser();
  parser.addOption('output', abbr: 'o', help: 'Output directory.');
  parser.addFlag('version', abbr: 'v', help: 'Print version number.');

  // Parse CLI args.
  final options = parser.parse(args);

  // If the version flag is set, print version and exit.
  if (options['version'] == true) {
    print('Omnibuild v$omnibuildBinaryVersion');
    return;
  }

  String outputDir = options['output'];

  // Read package name and version from pubspec.yaml.
  YamlMap pubspec = loadYaml(new File('./pubspec.yaml').readAsStringSync());
  String packageName = pubspec['name'];
  String packageVersion = pubspec['version'];
  var pubMajorVersion = int.parse(packageVersion[0]);

  // Loop through input files.
  var pathMatcher = new RegExp(r'.v(\d+).yaml$');
  options.rest.forEach((String filepath) {
    var r = pathMatcher.firstMatch(filepath);

    if (r == null) {
      // Show error message if the file does not contain a version number.
      print('No version number was found in $filepath (file skipped)');
    } else if (int.parse(r.group(1)) > pubMajorVersion) {
      // Show error message if the file version is larger than the pub major
      // version.
      print(
          'Pub major version ($pubMajorVersion) is smaller than the version of $filepath (file skipped)');
    } else {
      // Parse file.
      var spec = new OmnibuildSpecFile.fromYaml(
          new File(filepath).readAsStringSync(),
          int.parse(r.group(1)),
          packageName);

      // Generate code.
      var code = spec.generateCode();

      // Write to output file.
      new File(outputDir + path.basenameWithoutExtension(filepath) + '.dart')
          .writeAsStringSync(code);
    }
  });
}
